@@ -2,4 +2,4 @@
 # vim: ai ts=4 sts=4 et sw=4
 
 INSTALLED_HANDLERS = None
-EXCLUDED_HANDLERS = ['what']
+EXCLUDED_HANDLERS = []
