@@ -7,11 +7,11 @@ from . import views
 
 urlpatterns = patterns('',
 
-    url(r'^registration/$',
+    url(r'^$',
         views.registration,
         name="registration"),
 
-    url(r'^registration/(?P<pk>\d+)/edit/$',
+    url(r'^(?P<pk>\d+)/edit/$',
         views.registration,
         name="registration_edit")
 )
